@@ -1,11 +1,14 @@
 package B::Module::Info;
 
-$VERSION = '0.24';
+use 5.006;
+use strict;
+our $VERSION = '0.36';
 
 use B;
-use B::BUtils qw(walkoptree_filtered walkoptree_simple
-                 opgrep all_roots);
+use B::Utils 0.27 qw(walkoptree_filtered walkoptree_simple
+                     opgrep all_roots);
 @B::Utils::bad_stashes = qw();  # give us everything.
+our ($Start, $End, $File, $CurCV);
 
 =head1 NAME
 
@@ -185,9 +188,16 @@ my %modes = (
 
 sub const_sv {
     my $op = shift;
-    my $sv = $op->sv if $op->can('sv');
+    my $sv;
+    
+    if ($op->name eq 'method_named' && $op->can('meth_sv')) {
+        $sv = $op->meth_sv;
+    }
+    elsif ($op->can('sv')) {
+        $sv = $op->sv;
+    }
     # the constant could be in the pad (under useithreads)
-    $sv = padval($op->targ) unless $$sv;
+    $sv = padval($op->targ) unless ref($sv) && $$sv;
     return $sv;
 }
 
@@ -401,15 +411,19 @@ sub sub_check {
     }
     # function call
     else {
-        my($name_op) = grep($_->name eq 'gv', @kids);
-        if( $name_op ) {
-            my $gv = gv_or_padgv($name_op);
+        my $gv_op;
+        my ($filename, $line) = ($B::Utils::file, $B::Utils::line);
+        walkoptree_simple($op,
+            sub { my $op = shift; $gv_op = $op if $op->name eq 'gv'; }
+        );
+        if ($gv_op) {
+            my $gv = gv_or_padgv($gv_op);
             printf "function call to %s at \"%s\" line %d\n", 
-              $gv->NAME, $B::Utils::file, $B::Utils::line;
+              $gv->NAME, $filename, $line;
         }
         else {
             printf "function call using symbolic ref at \"%s\" line %d\n",
-              $B::Utils::file, $B::Utils::line;
+              $filename, $line;
         }
     }
 }
