@@ -1,16 +1,18 @@
 package Module::Info;
 
+use 5.006;
 use strict;
+use warnings;
 use Carp;
 use File::Spec;
 use Config;
-require 5.004;
 
 my $has_version_pm = eval 'use version; 1';
 
-use vars qw($VERSION @ISA $AUTOLOAD);
-# quotes 'version' for 5.004
-$VERSION = eval 'use version; 1' ? 'version'->new('0.35') : '0.35';
+our $AUTOLOAD;
+our $VERSION;
+
+$VERSION = eval 'use version; 1' ? 'version'->new('0.36') : '0.36';
 $VERSION = eval $VERSION;
 
 
